	.. -*- mode: rst -*-

ConPagnon
=========

ConPagnon is a Python module designed to facilitate the analysis
of Resting State data.

It leverages, among others, the `scikit-learn <http://scikit-learn.org>`_ Python toolbox,
and the `nilearn <http://nilearn.github.io/>`_ Python toolbox. ConPagnon
also contain numerous utilities for manipulating text data, visualizing
and plotting results.

Important links
===============

- Official source code repo: https://github.com/ConPagnon/conpagnon
- HTML documentation (stable release): https://conpagnon.github.io/conpagnon/index.html

Dependencies
============

The required dependencies to use the software are:

* Python >= 3.5,
* setuptools
* Numpy
* SciPy
* Scikit-learn
* Joblib
* Nibabel
* PyPDF2
* Webcolors
* Seaborn
* Pandas
* Statsmodels
* Psutil
* Networkx
* Patsy

Install
=======

First make sure you have installed all the dependencies listed above.
Then you can install ConPagnon by running the following command in
a command prompt::

    pip install conpagnon

More detailed instructions are available at
https://conpagnon.github.io/conpagnon/install.html.

Contributors
============

`Dhaif BEKHA`_

.. _Dhaif BEKHA: dhaif@dhaifbekha.com
